@@ -1,5 +1,8 @@
 import os
+import shutil
 import subprocess
+import tempfile
+from os.path import join, exists
 
 import mock
 from testify import setup_teardown, TestCase, test_program
@@ -123,34 +126,129 @@ class TestClientServerReturnCode(TestCase):
         assert_in('PASSED', ret)
         assert_equal(server_process.wait(), 0)
 
+
+class TestClientScheduling(TestCase):
+    @setup_teardown
+    def create_temporary_directory(self):
+        self.tempdir = tempfile.mkdtemp()
+        shutil.copy(
+            join('test', 'failing_test_after_signal.py'), self.tempdir,
+        )
+        try:
+            yield
+        finally:
+            shutil.rmtree(self.tempdir)
+
     def test_client_returns_nonzero_on_failure(self):
+        tempdir = self.tempdir
         server_process = subprocess.Popen(
             [
                 'python', '-m', 'testify.test_program',
-                'test.failing_test',
+                'failing_test_after_signal',
                 '--serve', '9001',
+                '--server-timeout', '10',
+                '-v',
+            ],
+            stdout=open(os.devnull, 'w'),
+            stderr=open(os.devnull, 'w'),
+            cwd=tempdir,
+        )
+
+        # Read from both of the processes until we get some output
+        # Then send sigint to that process
+        # We're doing this as a synchronization mechanism to guarantee
+        # two clients are connected to the server when the test fails.
+        # The expected behaviour is that the failed test is not re-run on
+        # the same client
+
+        class Client(object):
+            def __init__(self, number):
+                filename = join(tempdir, str(number) + '.stdout')
+                self.proc = subprocess.Popen(
+                    [
+                        'python', '-m', 'testify.test_program',
+                        '--connect', 'localhost:9001',
+                        '--runner-timeout', '5',
+                        '-v',
+                    ],
+                    stdout=open(filename , 'w'),
+                    stderr=open(os.devnull, 'w'),
+                    env=dict(os.environ, client_num=str(number)),
+                    cwd=tempdir,
+                )
+                self.number = number
+                self.ready = False
+                self.outfile = filename
+
+        clients = [Client(1), Client(2)]
+        while True:
+            for client in clients:
+                client.ready = exists(join(tempdir, str(client.number)))
+
+            if all(client.ready for client in clients):
+                # all ready!
+                break
+
+        # All of our tests are ready, send them 'go!' so they continue
+        with open(join(tempdir, 'go!'), 'w'):
+            pass
+
+        assert_equal(clients[0].proc.wait(), 1)
+        assert_equal(clients[1].proc.wait(), 1)
+        assert_equal(server_process.wait(), 1)
+
+        # The failing test should have been run on both clients
+        for client in clients:
+            client.output = open(client.outfile).read()
+            assert_in('Intentional failure!', client.output)
+
+        # The passing test should have been run on just one clients
+        assert_equal(set([True, False]), set([
+            'test_pass' in client.output
+            for client in clients
+        ]))
+
+        for client in clients:
+            if 'test_pass' in client.output:
+                assert_in(
+                    'FAILED.  2 tests / 2 cases: 1 passed, 1 failed.',
+                    client.output
+                )
+            else:
+                assert_in(
+                    'FAILED.  1 test / 1 case: 0 passed, 1 failed.',
+                    client.output,
+                )
+
+
+class Test240Regression(TestCase):
+    def _test(self, testname):
+        """Regression test for #240."""
+        server_process = subprocess.Popen(
+            [
+                'python', '-m', 'testify.test_program',
+                testname,
+                '--serve', '9001',
+                '-v',
             ],
             stdout=open(os.devnull, 'w'),
             stderr=open(os.devnull, 'w'),
         )
-        # Need two clients in order to finish running tests
         client_1 = subprocess.Popen(
             [
                 'python', '-m', 'testify.test_program',
                 '--connect', 'localhost:9001',
-            ],
-            stdout=open(os.devnull, 'w'),
-            stderr=open(os.devnull, 'w'),
-        )
-        client_2 = subprocess.Popen(
-            [
-                'python', '-m', 'testify.test_program',
-                '--connect', 'localhost:9001',
+                '-v',
             ],
             stdout=open(os.devnull, 'w'),
             stderr=open(os.devnull, 'w'),
         )
         assert_equal(client_1.wait(), 1)
-        assert_equal(client_2.wait(), 1)
         assert_equal(server_process.wait(), 1)
-            
+
+    def test_one_test_one_fail(self):
+        self._test('test.failing_test')
+
+    def test_lots_of_fails(self):
+        """Not sure why three fails triggers this behaviour as well..."""
+        self._test('test.lots_of_fail')
