@@ -181,7 +181,7 @@ class TestRunnerServerTestCase(TestRunnerServerBaseTestCase):
         first_test = get_test(self.server, 'runner1')
 
         assert_equal(first_test['class_path'], 'test.test_runner_server_test DummyTestCase')
-        assert_equal(first_test['methods'], ['test', 'run'])
+        assert_equal(set(first_test['methods']), set(['test', 'run']))
 
         self.run_test('runner1')
 
@@ -192,13 +192,13 @@ class TestRunnerServerTestCase(TestRunnerServerBaseTestCase):
         """Start a server with one test case to run. Make sure it hands out that test, report it as failure, then make sure it gives us the same one, then nothing else."""
         first_test = get_test(self.server, 'runner1')
         assert_equal(first_test['class_path'], 'test.test_runner_server_test DummyTestCase')
-        assert_equal(first_test['methods'], ['test', 'run'])
+        assert_equal(set(first_test['methods']), set(['test', 'run']))
 
         self.run_test('runner1', should_pass=False)
 
         second_test = get_test(self.server, 'runner2')
         assert_equal(second_test['class_path'], 'test.test_runner_server_test DummyTestCase')
-        assert_equal(second_test['methods'], ['test', 'run'])
+        assert_equal(set(second_test['methods']), set(['test', 'run']))
 
         self.run_test('runner2', should_pass=False)
 
@@ -221,14 +221,14 @@ class TestRunnerServerTestCase(TestRunnerServerBaseTestCase):
         assert second_test
 
         assert_equal(first_test['class_path'], second_test['class_path'])
-        assert_equal(first_test['methods'], second_test['methods'])
+        assert_equal(set(first_test['methods']), set(second_test['methods']))
         assert_equal(third_test, None)
 
     def test_disable_requeueing_on_failure(self):
         with disable_requeueing(self.server):
             first_test = get_test(self.server, 'runner1')
             assert_equal(first_test['class_path'], 'test.test_runner_server_test DummyTestCase')
-            assert_equal(first_test['methods'], ['test', 'run'])
+            assert_equal(set(first_test['methods']), set(['test', 'run']))
 
             self.run_test('runner1', should_pass=False)
 
@@ -245,7 +245,7 @@ class TestRunnerServerTestCase(TestRunnerServerBaseTestCase):
         with disable_requeueing(self.server):
             first_test = get_test(self.server, 'runner1')
             assert_equal(first_test['class_path'], 'test.test_runner_server_test DummyTestCase')
-            assert_equal(first_test['methods'], ['test', 'run'])
+            assert_equal(set(first_test['methods']), set(['test', 'run']))
 
             self.run_test('runner1', should_pass=False)
 
@@ -269,10 +269,10 @@ class TestRunnerServerTestCase(TestRunnerServerBaseTestCase):
 
 
         assert_equal(first_test['class_path'], second_test['class_path'])
-        assert_equal(first_test['methods'], second_test['methods'])
+        assert_equal(set(first_test['methods']), set(second_test['methods']))
 
         assert_equal(first_test['class_path'], third_test['class_path'])
-        assert_equal(first_test['methods'], third_test['methods'])
+        assert_equal(set(first_test['methods']), set(third_test['methods']))
 
         # Check that it didn't requeue again.
         assert_equal(get_test(self.server, 'runner4'), None)
@@ -289,9 +289,9 @@ class TestRunnerServerTestCase(TestRunnerServerBaseTestCase):
         third_test = get_test(self.server, 'runner3')
         self.run_test('runner3', should_pass=False)
         assert_equal(first_test['class_path'], second_test['class_path'])
-        assert_equal(first_test['methods'], second_test['methods'])
+        assert_equal(set(first_test['methods']), set(second_test['methods']))
         assert_equal(first_test['class_path'], third_test['class_path'])
-        assert_equal(first_test['methods'], third_test['methods'])
+        assert_equal(set(first_test['methods']), set(third_test['methods']))
 
         # Check that it didn't requeue again.
         assert_equal(get_test(self.server, 'runner4'), None)
@@ -304,11 +304,11 @@ class TestRunnerServerTestCase(TestRunnerServerBaseTestCase):
          - The server has more than one test in its queue
          - All the tests in the server's queue were last run by the runner asking for tests.
         """
-        self.server.test_queue = test_runner_server.AsyncDelayedQueue()
+        self.server.pair_queue = test_runner_server.AsyncDelayedQueue()
 
-        self.server.test_queue.put(0, {'last_runner': 'foo', 'class_path': '1', 'methods': ['blah'], 'fixture_methods': []})
-        self.server.test_queue.put(0, {'last_runner': 'foo', 'class_path': '2', 'methods': ['blah'], 'fixture_methods': []})
-        self.server.test_queue.put(0, {'last_runner': 'foo', 'class_path': '3', 'methods': ['blah'], 'fixture_methods': []})
+        self.server.pair_queue.add_test(0, {'last_runner': 'foo', 'class_path': '1', 'methods': ['blah'], 'fixture_methods': []})
+        self.server.pair_queue.add_test(0, {'last_runner': 'foo', 'class_path': '2', 'methods': ['blah'], 'fixture_methods': []})
+        self.server.pair_queue.add_test(0, {'last_runner': 'foo', 'class_path': '3', 'methods': ['blah'], 'fixture_methods': []})
 
         failures = []
 
@@ -430,7 +430,7 @@ class TestRunnerServerExceptionInSetupPhaseBaseTestCase(TestRunnerServerBaseTest
         assert_equal(expected_methods.symmetric_difference(seen_methods), set())
 
         # Verify the failed test case is re-queued for running.
-        assert_equal(self.server.test_queue.empty(), False)
+        assert_equal(self.server.pair_queue.empty(), False)
         requeued_test_case = get_test(self.server, 'runner2')
         assert_in(self.dummy_test_case.__name__, requeued_test_case['class_path'])
 
@@ -451,7 +451,7 @@ class TestRunnerServerExceptionInSetupPhaseBaseTestCase(TestRunnerServerBaseTest
         assert_equal(expected_methods.symmetric_difference(seen_methods), set())
 
         # Verify no more test cases have been re-queued for running.
-        assert_equal(self.server.test_queue.empty(), True)
+        assert_equal(self.server.pair_queue.empty(), True)
 
 class TestRunnerServerExceptionInClassSetupTestCase(TestRunnerServerExceptionInSetupPhaseBaseTestCase):
     def build_test_case(self):
@@ -498,7 +498,7 @@ class TestRunnerServerExceptionInTeardownPhaseBaseTestCase(TestRunnerServerBaseT
 
         # Verify the failed class_teardown method is not re-queued for running
         # -- it doesn't make sense to re-run a "flaky" class_teardown.
-        assert_equal(self.server.test_queue.empty(), True)
+        assert_equal(self.server.pair_queue.empty(), True)
 
 
 class TestRunnerServerExceptionInClassTeardownTestCase(TestRunnerServerExceptionInTeardownPhaseBaseTestCase):
